<?php
/**
 * @file
 * A standard chunk, used by automatic tests.
 */

module_load_include('inc', 'chunks', 'chunks.chunk');

class ChunksTestsNews extends ChunksChunk {

  function query() {

    // query elements: get all active articles
    $query = new EntityFieldQuery();
    $query
      ->entityCondition('entity_type', 'node')
      ->entityCondition('bundle', 'article')
      ->propertyCondition('status', 1)
      ->propertyOrderBy('created', 'DESC');

    // allow configuration: only display promoted articles
    if (isset($this->configuration['promoted']) && $this->configuration['promoted'] == TRUE) {
      $query->propertyCondition('promote', TRUE);
    }

    // execute query
    $results = $query->execute();

    // get articles
    $articles = node_load_multiple(array_keys($results['node']));

    // dispaly articles
    $this->view = node_view_multiple($articles, 'teaser');
  }

  static function title() {
    return t("Chunks example - News");
  }

  static function description() {
    return t("Display most recent articles.");
  }

  static public function configuration() {

    // allow the user to limit display to promoted articles.
    return array(
      'promoted' => array(
        '#type' => 'checkbox',
        '#title' => t('Only promoted articles'),
        '#default_value' => FALSE,
        '#description' => t('Only display articles, that are promoted to frontpage.'),
      ),
    );
  }

  public function validate() {

    // promoted can be set to TRUE, FALSE if defined
    if (isset($this->configuration['promoted'])) {
      return (($this->configuration['promoted'] == TRUE) || ($this->configuration['promoted'] == FALSE));
    }

    else {
      return TRUE;
    }
  }
}
